## Summary

## search

### DB Search

- API-access not available (per definition).
- Typical Excel column names include: ...
- Markdown files (*.md) containing a bibliography section (formatted references) are parsed upon `colrev load` based on GROBID.
